aind\_behavior\_curriculum.trainer.TrainerState
===============================================

.. currentmodule:: aind_behavior_curriculum.trainer

.. autoclass:: TrainerState
   :members:
   :show-inheritance:
   :inherited-members:

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~TrainerState.__init__
      ~TrainerState.construct
      ~TrainerState.copy
      ~TrainerState.default
      ~TrainerState.dict
      ~TrainerState.from_orm
      ~TrainerState.json
      ~TrainerState.model_construct
      ~TrainerState.model_copy
      ~TrainerState.model_dump
      ~TrainerState.model_dump_json
      ~TrainerState.model_json_schema
      ~TrainerState.model_parametrized_name
      ~TrainerState.model_post_init
      ~TrainerState.model_rebuild
      ~TrainerState.model_validate
      ~TrainerState.model_validate_json
      ~TrainerState.model_validate_strings
      ~TrainerState.parse_file
      ~TrainerState.parse_obj
      ~TrainerState.parse_raw
      ~TrainerState.schema
      ~TrainerState.schema_json
      ~TrainerState.update_forward_refs
      ~TrainerState.validate
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~TrainerState.model_computed_fields
      ~TrainerState.model_config
      ~TrainerState.model_extra
      ~TrainerState.model_fields
      ~TrainerState.model_fields_set
      ~TrainerState.curriculum
      ~TrainerState.stage
      ~TrainerState.is_on_curriculum
      ~TrainerState.active_policies
   
   